Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6984)

Unified Diff: chrome/browser/resources/ssl/ssl_error_assistant/gen_ssl_error_assistant_proto.py

Issue 2641423002: Rename TLS error assistant to SSL error assistant (Closed)
Patch Set: Year Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/ssl/ssl_error_assistant/gen_ssl_error_assistant_proto.py
diff --git a/chrome/browser/resources/ssl/tls_error_assistant/gen_tls_error_assistant_proto.py b/chrome/browser/resources/ssl/ssl_error_assistant/gen_ssl_error_assistant_proto.py
similarity index 69%
rename from chrome/browser/resources/ssl/tls_error_assistant/gen_tls_error_assistant_proto.py
rename to chrome/browser/resources/ssl/ssl_error_assistant/gen_ssl_error_assistant_proto.py
index 4ad676c629fc36ee0274a2fa06940c591bb575a1..0b546657c332483e93ce136b00a13c696b7e3ed5 100755
--- a/chrome/browser/resources/ssl/tls_error_assistant/gen_tls_error_assistant_proto.py
+++ b/chrome/browser/resources/ssl/ssl_error_assistant/gen_ssl_error_assistant_proto.py
@@ -4,28 +4,27 @@
# found in the LICENSE file.
"""
Convert the ASCII tls_error_assistant.asciipb proto into a binary resource.
"""
import os
import sys
# Import the binary proto generator. Walks up to the root of the source tree
-# which is six directories above, and the finds the protobufs directory from
-# there.
+# which is six directories above, and finds the protobufs directory from there.
proto_generator_path = os.path.normpath(os.path.join(os.path.abspath(__file__),
*[os.path.pardir] * 6 + ['chrome/browser/resources/protobufs']))
sys.path.insert(0, proto_generator_path)
from binary_proto_generator import BinaryProtoGenerator
-class TLSErrorAssistantProtoGenerator(BinaryProtoGenerator):
+class SSLErrorAssistantProtoGenerator(BinaryProtoGenerator):
def ImportProtoModule(self):
- import tls_error_assistant_pb2
- globals()['tls_error_assistant_pb2'] = tls_error_assistant_pb2
+ import ssl_error_assistant_pb2
+ globals()['ssl_error_assistant_pb2'] = ssl_error_assistant_pb2
def EmptyProtoInstance(self):
- return tls_error_assistant_pb2.TLSErrorAssistantConfig()
+ return ssl_error_assistant_pb2.SSLErrorAssistantConfig()
def ValidatePb(self, opts, pb):
assert pb.version_id > 0
@@ -38,7 +37,7 @@ class TLSErrorAssistantProtoGenerator(BinaryProtoGenerator):
def main():
- return TLSErrorAssistantProtoGenerator().Run()
+ return SSLErrorAssistantProtoGenerator().Run()
if __name__ == '__main__':
sys.exit(main())
@@ -4,28 +4,27 @@
# found in the LICENSE file.
"""
- Convert the ASCII tls_error_assistant.asciipb proto into a binary resource.
+ Convert the ASCII ssl_error_assistant.asciipb proto into a binary resource.
"""
import os

Powered by Google App Engine
This is Rietveld 408576698